==> haskell-configfile-1.1.4-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-7TGvjhgYTYwAhWmP9Jlwb2
key:                  ConfigFile-1.1.4-7TGvjhgYTYwAhWmP9Jlwb2
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  6192cd82631bbe1e98c52ccb555fe25b
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-7TGvjhgYTYwAhWmP9Jlwb2
depends:
    MissingH-1.6.0.1-2EJnGdIbdjf58rGJhza7du base-4.17.2.1
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ConfigFile
version:              1.1.4
visibility:           public
id:                   ConfigFile-1.1.4-BHQGDUxclro67WBEg56Pp1
key:                  ConfigFile-1.1.4-BHQGDUxclro67WBEg56Pp1
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2014 John Goerzen
maintainer:           John Goerzen <jgoerzen@complete.org>
author:               John Goerzen
stability:            Stable
homepage:             http://software.complete.org/configfile
synopsis:             Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.

    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.

    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.

category:             Parsing
abi:                  ca574a52214bef7104160103cfb4940f
exposed:              True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types

hidden-modules:       Data.ConfigFile.Lexer
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configfile
hs-libraries:         HSConfigFile-1.1.4-BHQGDUxclro67WBEg56Pp1
depends:
    MissingH-1.6.0.1-4mDI2kztnYZJjxDni2YkBr base-4.17.2.1
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1

haddock-interfaces:   /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html:         /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
